package org.xpresso.xml;

/**
 * The CDATA class is used to insert a CDATA block in the XML document.<br />
 * <br />
 * This code is under the <a href="http://www.gnu.org/licenses/lgpl.html">LGPL v3 licence</a>.
 * @author Alexis Dufrenoy
 */
public class CDATA extends XmlContent {

	/**
	 * 
	 */
	private static final long serialVersionUID = 7999675704408193494L;

	/**
	 * Constructs a CDATA block with the given String.
	 * @param text The content of the block
	 * @throws IllegalContentException Thrown if the given String contains the sequence "]]>"
	 */
	protected CDATA(String text) throws IllegalContentException {
		if (isValid(text)) {
			content = new StringBuilder();
			content.append("<![CDATA[")
				.append(text)
				.append("]]>");
		} else {
			throw new IllegalContentException("The string "+text+" is illegal as a XML CDATA");
		}
	}

	/**
	 * Check if the content given in parameter is valid to be used in a CDATA block.
	 * @param content The content to be checked
	 * @return false if the given String contains the sequence "]]>", true if not
	 */
	public static boolean isValid(String content) {
		boolean ret=true;
		if (content.contains("]]>")) {
			ret=false;
		}
		return ret;
	}

}
