package org.xpresso.xml;

/**
 *
 * The Comment class is used to insert a comment block in the XML document.<br />
 * <br />
 * This code is under the <a href="http://www.gnu.org/licenses/lgpl.html">LGPL v3 licence</a>.
 * @author Alexis Dufrenoy
 *
 */
public class Comment extends XmlContent {

	/**
	 * 
	 */
	private static final long serialVersionUID = 5521116578962345724L;

	/**
	 * Constructs a comment block with the given String
	 * @param text The content of the block
	 * @throws IllegalContentException Thrown if the given String contains the sequence "-->"
	 */
	protected Comment(String text) throws IllegalContentException {
		if (isValid(text)) {
			content = new StringBuilder();
			content.append("<!--")
				.append(text)
				.append("-->");
		} else {
			throw new IllegalContentException("The string "+text+" is illegal as a XML comment");
		}
	}

	/**
	 * Check if the content given in parameter is valid to be used in a comment block.
	 * @param content The content to be checked
	 * @return false if the given String contains the sequence "-->", true if not
	 */
	public static boolean isValid(String content) {
		boolean ret=true;
		if (content.contains("-->")) {
			ret=false;
		}
		return ret;
	}

}
